# Material-UI toast redux

using material ui `Snackbar` and `redux` for creating toast component

checkout [live demo](https://mohsensaremi.github.io/material-ui-toast-redux/).

## configuration

### redux
add toast reducer 
```
import {createStore, combineReducers} from 'redux';
import {reducer as toast} from 'material-ui-toast-redux';

const reducers = combineReducers({
    toast,
});

export default createStore(reducers);
```
(note: reducer name must be `toast`)

### react
add `Toast` component in one of your first component. you should mount this component only once in your components tree
```
import React from 'react';
import {Toast} from 'material-ui-toast-redux';

const App = () => (
    <div>
        <Header/>
        <Content/>
        <Footer/>
        .
        .
        .
        
        <Toast/>
    </div>
)
```

## withToast HOC
you can use `withToast` hoc to inject `openToast` function into component props. 
```
import {withToast} from 'material-ui-toast-redux';

const MyComponent = (props) => (
    <button
        onClick={()=>{
            props.openToast({
                messages: ['sample message'],
                type: 'success',
                autoHideDuration: 6000,
            });
        }}
    >
        open toast
    </button>
)

export default withToast(MyComponent);
```

## options

name | type | value | required | description
--- | --- | --- | --- | --- 
messages | array | `any array of string []` | yes | array of messages to display on toast. each item displayed in on line
type | string | `enum (success,error,warning,info)` | yes | for color and icon displayed in toast
autoHideDuration | number | `6000` | no | duration in millisecond for close toast

## test
```
not implemented yet
```